#!/usr/local/bin/perl
#

#-------------------------------------------------------------------------------
# INPUT FORMAT : amarok rafio file 
#-------------------------------------------------------------------------------
# new Station( name, url, website )
# new Station( "Metro (FM 95.1 Buenos Aires)",            "mmsh://201.212.5.144/metro?MSWMExt=.asf", "http://www.metro951.com/"),

#-------------------------------------------------------------------------------
# OUTPUT FORMAT : yarock xspf radio file
#-------------------------------------------------------------------------------
#  <?xml version="1.0" encoding="UTF-8"?>
#  <playlist version="1" xmlns="http://xspf.org/ns/0/">
#  <title> playlist title</title>
#  <annotation>
#  annotate with author, date, comments
#  </annotation>
#  
#  <tracklist>
#  <track>
#  <title>title name</title>
#  <location> url </location>
#  <extension application="yarock"><category> category name </category></extension>
#  </track>
#  </tracklist>
#  </playlist>


use strict;

#-------------------------------------------------------------------------------
# MAIN
#-------------------------------------------------------------------------------
die "Usage : amarok2yarock.pl <amarok radio directory>" unless (@ARGV == 1);

# chemin d'accs au repertoire des sources
   my $dir_path        = $ARGV[0]; 

# ouverture du repertoire contenant les sources
	 opendir DIR, $dir_path or die "Cannot open $dir_path $!";
	 closedir DIR;
 	 my $amarok_spec = $dir_path."script.spec";
   my $amarok_main = $dir_path."main.js";

# ouverture du fichiers .spec
   open(INFILE, $amarok_spec) or die "Impossible d'ouvrir $amarok_spec en lecture : $!";
   print "\nReading $amarok_spec file !\n";
  
   my $playlist_name = "undefined playlist name";
   while (my $line = <INFILE>) {
    chomp $line;
 	  if ($line =~ /^Name=([\w\d\s]+$)/i) {
     $playlist_name = $1;
    }
   }
  
  print "-> playlist name = ".$playlist_name;
  close INFILE;

# write yarock xspf file
	 my $resultfile = $dir_path.$playlist_name.".xspf";
   open(RESULT_FILE, ">$resultfile") or die "Impossible d'ouvrir $resultfile en cration : $!";
  
   print "\n-> output file set to ".$resultfile." !\n";
  
   print RESULT_FILE "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
   print RESULT_FILE "<playlist version=\"1\" xmlns=\"http://xspf.org/ns/0/\">\n";
   print RESULT_FILE "<title>".$playlist_name."</title>\n";
   print RESULT_FILE "<annotation>created by amarok2yarock.pl script</annotation>\n";
   print RESULT_FILE "\n";
   print RESULT_FILE "<tracklist>\n\n";
   
# ouverture du fichiers main.js
  open(INFILE, $amarok_main) or die "Impossible d'ouvrir $amarok_main en lecture : $!";
   print "\nReading $amarok_main file !\n";
   
  my $category_name = $playlist_name;
  while (my $line = <INFILE>) {
    chomp $line;
 	  if ($line =~ /^[\s\t]*categories\[\"([\w\W\d]*)\"/i) {
      $category_name = $1;
      print "CATEGORY = ".$category_name."\n";
      print RESULT_FILE "\n<!-- category = ".$category_name." -->\n";    
    }
    elsif ($line =~ /Station[\s\t]*\([\s\t]*\"([^\"]*)[\s\t]*\"[\s\t]*,[\s\t]*\"([^\"]*)\"/i) {
      #print $line."\n";
      print "Station name = ".$1."\n";
      print "Station url = ".$2."\n";
      
      print RESULT_FILE "<track>";      
      print RESULT_FILE "<title>".$1."</title>";      
      print RESULT_FILE "<location>".$2."</location>";
      print RESULT_FILE "<extension application=\"yarock\">";
      print RESULT_FILE "<category>".$category_name."</category></extension>";
      print RESULT_FILE "</track>\n";      
    }
  }
  
  close INFILE;
  
# write end of yarock xspf file
   print RESULT_FILE "</tracklist>\n";
   print RESULT_FILE "</playlist>\n";
   close RESULT_FILE;




